==> huaweicloudsdkcoc-3.1.140-py2.py3-none-any.whl: huaweicloudsdkcoc/v1/model/batch_create_application_view_request_body_component_list.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class BatchCreateApplicationViewRequestBodyComponentList:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'name': 'str',
        'parent_name': 'str'
    }

    attribute_map = {
        'name': 'name',
        'parent_name': 'parent_name'
    }

    def __init__(self, name=None, parent_name=None):
        """BatchCreateApplicationViewRequestBodyComponentList

        The model defined in huaweicloud sdk

        :param name: 名称
        :type name: str
        :param parent_name: 父节点code
        :type parent_name: str
        """
        
        

        self._name = None
        self._parent_name = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if parent_name is not None:
            self.parent_name = parent_name

    @property
    def name(self):
        """Gets the name of this BatchCreateApplicationViewRequestBodyComponentList.

        名称

        :return: The name of this BatchCreateApplicationViewRequestBodyComponentList.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this BatchCreateApplicationViewRequestBodyComponentList.

        名称

        :param name: The name of this BatchCreateApplicationViewRequestBodyComponentList.
        :type name: str
        """
        self._name = name

    @property
    def parent_name(self):
        """Gets the parent_name of this BatchCreateApplicationViewRequestBodyComponentList.

        父节点code

        :return: The parent_name of this BatchCreateApplicationViewRequestBodyComponentList.
        :rtype: str
        """
        return self._parent_name

    @parent_name.setter
    def parent_name(self, parent_name):
        """Sets the parent_name of this BatchCreateApplicationViewRequestBodyComponentList.

        父节点code

        :param parent_name: The parent_name of this BatchCreateApplicationViewRequestBodyComponentList.
        :type parent_name: str
        """
        self._parent_name = parent_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BatchCreateApplicationViewRequestBodyComponentList):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcoc-3.1.148-py2.py3-none-any.whl: huaweicloudsdkcoc/v1/model/batch_create_application_view_request_body_component_list.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class BatchCreateApplicationViewRequestBodyComponentList:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'name': 'str',
        'parent_name': 'str'
    }

    attribute_map = {
        'name': 'name',
        'parent_name': 'parent_name'
    }

    def __init__(self, name=None, parent_name=None):
        r"""BatchCreateApplicationViewRequestBodyComponentList

        The model defined in huaweicloud sdk

        :param name: 名称
        :type name: str
        :param parent_name: 父节点code
        :type parent_name: str
        """
        
        

        self._name = None
        self._parent_name = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if parent_name is not None:
            self.parent_name = parent_name

    @property
    def name(self):
        r"""Gets the name of this BatchCreateApplicationViewRequestBodyComponentList.

        名称

        :return: The name of this BatchCreateApplicationViewRequestBodyComponentList.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        r"""Sets the name of this BatchCreateApplicationViewRequestBodyComponentList.

        名称

        :param name: The name of this BatchCreateApplicationViewRequestBodyComponentList.
        :type name: str
        """
        self._name = name

    @property
    def parent_name(self):
        r"""Gets the parent_name of this BatchCreateApplicationViewRequestBodyComponentList.

        父节点code

        :return: The parent_name of this BatchCreateApplicationViewRequestBodyComponentList.
        :rtype: str
        """
        return self._parent_name

    @parent_name.setter
    def parent_name(self, parent_name):
        r"""Sets the parent_name of this BatchCreateApplicationViewRequestBodyComponentList.

        父节点code

        :param parent_name: The parent_name of this BatchCreateApplicationViewRequestBodyComponentList.
        :type parent_name: str
        """
        self._parent_name = parent_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BatchCreateApplicationViewRequestBodyComponentList):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
